﻿using Hotline.CallCenter.Calls;
using Hotline.Share.Dtos.Snapshot;
using Hotline.Users;
using Microsoft.Extensions.Logging;
using Senparc.CO2NET.Extensions;
using Senparc.Weixin;
using Senparc.Weixin.WxOpen.AdvancedAPIs.Sns;
using Senparc.Weixin.WxOpen.AdvancedAPIs.WxApp;
using System.Configuration;
using XF.Domain.Dependency;

namespace Hotline.WeChat;

public class WeChatService : IThirdIdentiyService
{
    private readonly ILogger<WeChatService> _logger;

    public WeChatService(ILogger<WeChatService> logger)
    {
        _logger = logger;
    }

    public async Task<ThirdTokenOutDto> GetTokenAsync(ThirdTokenDto dto)
    {
        var result = await SnsApi.JsCode2JsonAsync(dto.AppId, dto.Secret, dto.Code);
        if (result.errcode != ReturnCode.请求成功) return new ThirdTokenOutDto();
        return new ThirdTokenOutDto() { SessionKey = result.session_key , OpenId = result.openid};
    }

    /// <summary>
    /// 获取手机号码
    /// </summary>
    /// <param name="dto"></param>
    /// <returns></returns>
    public async Task<ThirdPhoneOutDto> GetPhoneNumberAsync(ThirdTokenDto dto)
    {
        _logger.LogInformation($"GetPhoneNumberAsync: {dto.ToJson()}");
        var result = await BusinessApi.GetUserPhoneNumberAsync(dto.AppId, dto.Code);
        if (result.errcode != ReturnCode.请求成功)
            _logger.LogError($"GetPhoneNumberAsync: {result.ToJson()}");
        return new ThirdPhoneOutDto() {
            ErrorCode = (int)result.errcode,
            IsError = result.errcode != ReturnCode.请求成功,
            ErrorMessage = result.errmsg,
            PhoneNumber = result.phone_info.phoneNumber 
        };
    }
}
